package org.apache.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.maven.project.Project;

/**
 * Base class from which all components in maven are derived.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 *
 * @version $Id: AbstractMavenComponent.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public abstract class AbstractMavenComponent
{
    /** Maven project. */
    private Project project;

    /** Default Constructor. */
    public AbstractMavenComponent()
    {
    }

    /**
     * Create a component that uses a project
     * @param aProject a Maven project
     */
    public AbstractMavenComponent( final Project aProject )
    {
        project = aProject;
    }

    /**
     * set the project property
     * @param aProject a Maven project
     */
    public void setProject( final Project aProject )
    {
        project = aProject;
    }

    /**
     * @return the project property
     */
    public Project getProject()
    {
        return project;
    }

    /**
     * Retrieve a user message.
     *
     * @param messageId Id of message type to use.
     * @return Message for the user's locale.
     * @see MavenUtils#getMessage
     */
    public String getMessage( final String messageId )
    {
        return MavenUtils.getMessage( messageId );
    }

    /**
     * Retrieve a user message.
     *
     * @param messageId Id of message type to use.
     * @param variable Value to substitute for ${1} in the given message.
     * @return Message for the user's locale.
     * @see MavenUtils#getMessage
     */
    public String getMessage( final String messageId, final Object variable )
    {
        return MavenUtils.getMessage( messageId, variable );
    }
}
