package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.commons.jelly.tags.ant.AntTagLibrary;
import org.apache.maven.jelly.tags.BaseTagSupport;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.Path;

/**
 * This class takes a given path using an <code>id</code> and appends another
 * path (using <code>refid</code>) to it.
 *
 * @author Bob McWhirter
 * @version $Id: AddPathTag.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class AddPathTag
    extends BaseTagSupport
{
    /** the id of the path to be appended to. */
    private String id;

    /** the path to append */
    private String refid;

    /**
     * Perform the tag processing. Look up the path by {@link #getId id} and append
     * the {@link #getRefid other path} to it.
     *
     * @param output used to write output
     * @throws JellyTagException when anything goes wrong.
     */
    public void doTag( XMLOutput output )
        throws JellyTagException
    {
        Project project = AntTagLibrary.getProject( getContext() );

        if ( project == null )
        {
            throw new JellyTagException( "cannot find ant project" );
        }

        checkAttribute( getId(), "id" );
        checkAttribute( getRefid(), "refid" );

        Path path = (Path) project.getReferences().get( getId() );
        if ( path == null )
        {
            throw new JellyTagException( "cannot find the path to add to specified by 'id': " + getId() );
        }
        Path addPath = (Path) project.getReferences().get( getRefid() );
        if ( addPath == null )
        {
            throw new JellyTagException( "cannot find the path to add specified by 'refid': " + getRefid() );
        }
        path.append( addPath );
    }

    /**
     * Setter for the id property
     *
     * @param pathId the reference id of the path in the ant project that will be
     * appended to
     */
    public void setId( String pathId )
    {
        id = pathId;
    }

    /**
     * Getter for the id property
     *
     * @return the reference id of the path in the ant project that will be
     * appended to
     */
    public String getId()
    {
        return id;
    }

    /**
     * Setter for the refid property
     *
     * @param pathToAppendId the reference id of the path in the ant project that will
     * be appended
     */
    public void setRefid( String pathToAppendId )
    {
        refid = pathToAppendId;
    }

    /**
     * Getter for the refid property
     *
     * @return the reference id of the path in the ant project that will be
     * appended
     */
    public String getRefid()
    {
        return refid;
    }
}
