package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.List;

import org.apache.maven.project.Project;

/**
 * @author <a href="mailto:bwalding@apache.org">Ben Walding</a>
 * @version $Id: DependencyResolverInterface.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public interface DependencyResolverInterface
{
    /**
     * Clear the project list and set the graph built flag to false.
     */
    void clear();

    /**
     * Set a list of projects to process.
     *
     * @param projects List of projects.
     */
    void setProjects( List projects );

    /**
     * Get the list of projects in dependency sorted order.
     *
     * @param project The project to use as the head of the graph.
     * @return The list of projects.
     * @throws DependencyResolverException If an error occurs while processing the graph.
     */
    List getSortedDependencies( Project project )
        throws DependencyResolverException;

    /**
     * Get the list of projects in dependency sorted order.
     *
     * @param project     The project to use as the head of the graph.
     * @param sourceBuild Indicate we are performing a source build.
     * @return The list of projects.
     * @throws DependencyResolverException If an error occurs while processing the graph.
     */
    List getSortedDependencies( Project project, boolean sourceBuild )
        throws DependencyResolverException;

    /**
     * Get the list of projects in dependency sorted order.
     *
     * @param sourceBuild Flag to indicate we are performing a source build.
     * @return The list of projects.
     * @throws DependencyResolverException If an error occurs while processing the graph.
     */
    List getSortedDependencies( boolean sourceBuild )
        throws DependencyResolverException;
}
