package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.XMLOutput;

/**
 * Concat a set of files together into a single file.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: InputTag.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class InputTag
    extends MavenTag
{
    /** Output file. */
    private File file;

    /** Set output file. */
    public void setFile( File file )
    {
        this.file = file;
    }

    /**
     * Perform functionality provided by the tag.
     *
     * @throws JellyTagException If there is an error while concatenating the file.
     */
    public void doTag( XMLOutput output )
        throws JellyTagException
    {
        ConcatTag tag = (ConcatTag) findAncestorWithClass( ConcatTag.class );

        if ( tag == null )
        {
            throw new JellyTagException( "no current concatenation" );
        }

        tag.addFile( file );
    }
}
