package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.jelly.tags.BaseTagSupport;
import org.apache.maven.plugin.PluginManager;

/**
 * A Maven Jelly tag that will install a given plugin JAR using the plugin manager.
 *
 * @author <a href="mailto:brett@apache.org">Brett Porter</a>
 * @version $Id: InstallPluginTag.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class InstallPluginTag
    extends BaseTagSupport
{
    private File file;

    private boolean cache = false;

    public void setCache( boolean cache )
    {
        this.cache = cache;
    }

    public void setFile( File file )
    {
        this.file = file;
    }

    /* (non-Javadoc)
     * @see org.apache.commons.jelly.Tag#doTag(org.apache.commons.jelly.XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        checkAttribute( file, "file" );

        PluginManager manager = getMavenContext().getMavenSession().getPluginManager();
        try
        {
            manager.installPlugin( file, null, cache );
        }
        catch ( Exception e )
        {
            throw new JellyTagException( "error installing plugin", e );
        }
    }
}
