package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.jelly.tags.BaseTagSupport;

/**
 * A tag to check parameters are being passed correctly
 */
public class ParamCheck
    extends BaseTagSupport
{
    /** the value to check */
    private String value;

    /** the message to display when value is empty */
    private String message;

    /** whether to fail or not */
    private boolean fail;

    /* (non-Javadoc)
     * @see org.apache.commons.jelly.Tag#doTag(org.apache.commons.jelly.XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws JellyTagException
    {
        if ( ( value == null ) || "".equals( value.trim() ) )
        {
            if ( fail )
            {
                throw new JellyTagException( getMessage() );
            }
            else
            {
                System.out.println( getMessage() );
            }
        }
    }

    /**
     * @param failOrNot whether this tag should throw an exception if the value is empty
     */
    public void setFail( boolean failOrNot )
    {
        fail = failOrNot;
    }

    /**
     * @return the message field if not null, or the body of the tag if it is
     */
    public String getMessage()
        throws JellyTagException
    {
        if ( message == null )
        {
            return getBodyText();
        }
        else
        {
            return message;
        }

    }

    /**
     * @param string the message to display when the value is empty
     */
    public void setMessage( String string )
    {
        message = string;
    }

    /**
     * @param string the value to check
     */
    public void setValue( String string )
    {
        value = string;
    }

}
