package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.MavenUtils;
import org.apache.maven.jelly.tags.BaseTagSupport;

/**
 * MavenSession Jelly tag that creates a POM instance.
 * By default, the inheritance in the POM isn't used.
 * You must use the attribute useInheritance to activate it.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: PomTag.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class PomTag
    extends BaseTagSupport
{
    /** MavenSession project descriptor. */
    private File projectDescriptor;

    /** Name of var to give the project object. */
    private String var;

    /** Define if the pom must use the inheritance. */
    private boolean useInheritance;

    /**
     * Set MavenSession project descriptor.
     *
     * @param projectDescriptor the file name of the maven project descriptor
     */
    public void setProjectDescriptor( File projectDescriptor )
    {
        this.projectDescriptor = projectDescriptor;
    }

    /**
     * Set var name for the POM.
     *
     * @param var Variable name for the pom.
     */
    public void setVar( String var )
    {
        this.var = var;
    }

    /**
     * Define if the pom must use the inheritance. 
     * Setted to false by default to keep a backward compatibility.
     * @param useInheritance true if the pom object must use the inheritance.
     */
    public void setUseInheritance( boolean useInheritance )
    {
        this.useInheritance = useInheritance;
    }

    /**
     * Perform functionality provided by the tag
     * @param output the place to write output
     * @throws JellyTagException when the projectDescriptor attribute is missing, or
     *      another error occurs
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        // Check to make sure that we have a valid POM
        // before processing.
        checkAttribute( projectDescriptor, "projectDescriptor" );
        checkAttribute( var, "var" );

        try
        {
            context.setVariable( var, MavenUtils.getProject( projectDescriptor, getMavenContext(), useInheritance ) );
        }
        catch ( Exception e )
        {
            throw new JellyTagException( "error getting project", e );
        }
    }
}
