package org.apache.maven.util;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.Arrays;
import java.util.List;

import org.codehaus.plexus.util.StringUtils;

/**
 * @author <a href="mailto:bwalding@jakarta.org">Ben Walding</a>
 * @version $Id: StringTool.java 517014 2007-03-11 21:15:50Z ltheussl $
 * @todo move to org.apache.maven.util or make a jelly tag
 */
public class StringTool
{

    /**
     * Splits a string at the last delimiter. If no delimiter is found,
     * first element is the string, second element is empty string.
     * @param s the string to be split
     * @param delim the delimiter
     * @return String[] a two element array, element 0 = string up to last delim (exclusive), element 1 = string past
     * last delim (exclusive)
     */
    public List splitStringAtLastDelim( String s, String delim )
    {
        if ( s == null )
        {
            String[] result = { null, null };
            return Arrays.asList( result );
        }

        int index = s.lastIndexOf( delim );

        if ( index == -1 )
        {
            String[] result = { s, "" };
            return Arrays.asList( result );
        }
        else
        {
            String[] result = { s.substring( 0, index ), s.substring( index + 1 ) };
            return Arrays.asList( result );
        }
    }

    /**
     * <p>Removes all whitespace characters from the start and end of a String.</p>
     *
     * <p>This is similar to {@link #trim(String)} but removes whitespace.
     * Whitespace is defined by {@link Character#isWhitespace(char)}.</p>
     *
     * @param s the String to remove characters from, may be null
     * @return the trimmed String, <code>null</code> if null String input
     */
    public static String trim( String s )
    {
        return StringUtils.strip( s );
    }
}
