package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.Iterator;
import java.util.List;

import junit.framework.TestCase;

import org.apache.maven.project.Project;

/**
 * @author <a href="bwalding@jakarta.org">Ben Walding</a>
 * @version $Id: DependencyResolverTest.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class DependencyResolverTest
    extends TestCase
{
    private WerkzDependencyResolver dri;

    public void testSimple1()
        throws Exception
    {
        List projects = DependencyResolverTestData.getTestSimple1();
        testSimple1Source( dri, projects );
        testSimple1Binary( dri, projects );
    }

    public void testSimple2()
        throws Exception
    {
        List projects = DependencyResolverTestData.getTestSimple2();
        testSimple2( dri, projects );
    }

    public void testSimple3()
        throws Exception
    {
        List projects = DependencyResolverTestData.getTestSimple3();
        testSimple3( dri, projects );
    }

    public void testComplex()
        throws Exception
    {
        List projects = DependencyResolverTestData.getTestComplex();
        testComplex( dri, projects );
    }

    public void testCycle()
        throws Exception
    {
        List projects = DependencyResolverTestData.getTestCycle();
        testCycle( dri, projects );
    }

    public void testCycle( DependencyResolverInterface dri, List projects )
        throws Exception
    {
        DependencyResolver dr = new DependencyResolver( dri );
        dr.setProjects( projects );
        try
        {
            dr.getSortedDependencies( true );
            fail( "Shouldn't be able to resolve cycles" );
        }
        catch ( Exception e )
        {
            //Success
        }

        try
        {
            dr.getSortedDependencies( false );
            fail( "Shouldn't be able to resolve cycles" );
        }
        catch ( Exception e )
        {
            //Success
        }
    }

    public void testSimple1Source( DependencyResolverInterface dri, List projects )
        throws Exception
    {
        DependencyResolver dr = new DependencyResolver( dri );
        dr.setProjects( projects );

        assertEquals( "test1.sorted", "b:b,e:e,n:n,j:j", listify( dri.getSortedDependencies( true ) ) );

        projects = dr.getSortedDependencies( true );
        assertBefore( projects, "b:b", "e:e" );
        assertBefore( projects, "e:e", "n:n" );
        assertBefore( projects, "n:n", "j:j" );

        Project e = DependencyResolver.getProject( projects, "e:e" );
        assertEquals( "test1.sorted", "b:b,e:e", listify( dri.getSortedDependencies( e, true ) ) );
        Project n = DependencyResolver.getProject( projects, "n:n" );
        assertEquals( "test1.sorted", "b:b,e:e,n:n", listify( dri.getSortedDependencies( n, true ) ) );
        Project j = DependencyResolver.getProject( projects, "j:j" );
        assertEquals( "test1.sorted", "b:b,e:e,n:n,j:j", listify( dri.getSortedDependencies( j, true ) ) );
    }

    /**
     * @todo THIS IS A DUPLICATE of testSimple1Source
     * @param dri dependency resolver
     * @param projects list of projects to resolve
     * @throws Exception when anything happens
     */
    public void testSimple1Binary( DependencyResolverInterface dri, List projects )
        throws Exception
    {
        testSimple1Source( dri, projects );
    }

    public void testSimple2( DependencyResolverInterface dri, List projects )
        throws Exception
    {
        dri.setProjects( projects );
        projects = dri.getSortedDependencies( true );

        assertEquals( "test3.sorted", "th:th,eq:eq,ui:ui,ck:ck,br:br,ow:ow,nf:nf,ox:ox", listify( dri
            .getSortedDependencies( true ) ) );
        Project eq = DependencyResolver.getProject( projects, "eq:eq" );
        assertEquals( "test3.sorted", "th:th,eq:eq", listify( dri.getSortedDependencies( eq, true ) ) );
        Project ck = DependencyResolver.getProject( projects, "ck:ck" );
        assertEquals( "test3.sorted", "th:th,eq:eq,ui:ui,ck:ck", listify( dri.getSortedDependencies( ck, true ) ) );
        Project ow = DependencyResolver.getProject( projects, "ow:ow" );
        assertEquals( "test3.sorted", "th:th,eq:eq,ui:ui,ck:ck,br:br,ow:ow",
                      listify( dri.getSortedDependencies( ow, true ) ) );
    }

    public void testSimple3( DependencyResolverInterface dri, List projects )
        throws Exception
    {
        dri.setProjects( projects );
        projects = dri.getSortedDependencies( true );

        assertEquals( "test2.sorted", "th:th,eq:eq,ui:ui,ck:ck,br:br,ow:ow,nf:nf,ox:ox", listify( dri
            .getSortedDependencies( true ) ) );
        Project eq = DependencyResolver.getProject( projects, "eq:eq" );
        assertEquals( "test3.sorted", "th:th,eq:eq", listify( dri.getSortedDependencies( eq, true ) ) );
        Project ck = DependencyResolver.getProject( projects, "ck:ck" );
        assertEquals( "test3.sorted", "th:th,eq:eq,ui:ui,ck:ck", listify( dri.getSortedDependencies( ck, true ) ) );
        Project ow = DependencyResolver.getProject( projects, "ow:ow" );
        assertEquals( "test3.sorted", "th:th,eq:eq,ui:ui,ck:ck,br:br,ow:ow",
                      listify( dri.getSortedDependencies( ow, true ) ) );
    }

    public void testComplex( DependencyResolverInterface dri, List projects )
        throws Exception
    {
        dri.setProjects( projects );
        //System.out.println("Source DepResolver:" + dri.getClass().getName());
        projects = dri.getSortedDependencies( true );
        //dumpList(projects);
        assertEquals( "SourceDep.size()", projects.size(), 12 );
        assertBefore( projects, "tyre:tyre", "car:car" );
        assertBefore( projects, "rubber:rubber", "tyre:tyre" );
        assertBefore( projects, "beer:beer", "driver:driver" );

        //System.out.println("Binary DepResolver:" + dri.getClass().getName());
        projects = dri.getSortedDependencies( false );
        //dumpList(projects);
        assertEquals( "SourceDep.size()", projects.size(), 5 );
        assertBefore( projects, "hops:hops", "beer:beer" );
        assertBefore( projects, "tyre:tyre", "car:car" );
        assertBefore( projects, "beer:beer", "driver:driver" );

    }

    public void dumpList( List projects )
    {
        Iterator iter = projects.iterator();
        while ( iter.hasNext() )
        {
            Project project = (Project) iter.next();
            System.out.println( project.getId() );
        }
    }

    public void assertBefore( List projects, String first, String second )
    {
        assertTrue( first + " earlier than " + second, getIndex( projects, first ) < getIndex( projects, second ) );
    }

    public int getIndex( List projects, String id )
    {
        for ( int i = 0; i < projects.size(); i++ )
        {
            Project p = (Project) projects.get( i );
            if ( p.getId().equals( id ) )
            {
                return i;
            }
        }
        throw new IllegalArgumentException( "No such project: " + id );
    }

    public String listify( List projects )
    {
        StringBuffer buf = new StringBuffer();
        Iterator iter = projects.iterator();
        while ( iter.hasNext() )
        {
            Project project = (Project) iter.next();
            buf.append( project.getId() );
            if ( iter.hasNext() )
            {
                buf.append( "," );
            }
        }
        return buf.toString();
    }

    protected void setUp()
        throws Exception
    {
        super.setUp();
        dri = new WerkzDependencyResolver();
    }
}
