package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

/**
 * Tests for {@link RootRelativePathTag}.
 * 
 * @author <a href="mailto:vmassol@apache.org">Vincent Massol</a>
 * @version $Id: RootRelativePathTagTest.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class RootRelativePathTagTest
    extends TestCase
{
    /**
     * The tag to test
     */
    private RootRelativePathTag tag;

    /**
     * @see TestCase#setUp()
     */
    protected void setUp()
    {
        tag = new RootRelativePathTag();
    }

    public void testComputePathOk()
        throws Exception
    {
        tag.setPath( "c:/apps/myproject/path/subproject2" );
        tag.setRootdir( new File( "c:/apps/myproject" ) );
        String result = tag.computePath();
        assertEquals( "./../..", result );
    }

    public void testComputePathWithEndingSeparator()
        throws Exception
    {
        tag.setPath( "c:/apps/myproject/path/subproject2" );
        tag.setRootdir( new File( "c:/apps/myproject/" ) );
        String result = tag.computePath();
        assertEquals( "./../..", result );
    }

    public void testComputePathOk2()
        throws Exception
    {
        tag.setPath( "c:/apps/myproject" );
        tag.setRootdir( new File( "c:/apps/myproject" ) );
        String result = tag.computePath();
        assertEquals( ".", result );
    }

    public void testComputePathOk3()
        throws Exception
    {
        tag.setPath( "c:\\apps\\myproject\\path\\subproject2" );
        tag.setRootdir( new File( "c:\\apps\\myproject" ) );
        String result = tag.computePath();
        assertEquals( "./../..", result );
    }

    public void testComputePathWhenPathNotSubsetRootdir()
        throws Exception
    {
        tag.setPath( "c:/apps/myproject/path/subproject2" );
        tag.setRootdir( new File( "c:/somethingelse" ) );

        try
        {
            tag.computePath();
            fail( "should have thrown an exception" );
        }
        catch ( IOException expected )
        {
            assertTrue( true );
        }
    }
}
