package org.apache.maven.plugin;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import junit.framework.TestCase;

import org.apache.maven.MavenException;

/**
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: PluginCacheManagerTest.java,v 1.1 2002/12/31 07:10:06 jvanzyl
 *      Exp $
 */
public class PluginCacheManagerTest
    extends TestCase
{
    private static String PLUGIN_SCRIPT = System.getProperty( "basedir" )
        + "/src/test/java/org/apache/maven/plugin/plugin.jelly";

    /**
     * Constructor.
     *
     * @param name Name of the test.
     */
    public PluginCacheManagerTest( String name )
    {
        super( name );
    }

    /**
     * Test the plugin cache builder.
     */
    public void testPluginGraphBuilder()
        throws FileNotFoundException, IOException, MavenException
    {
        PluginCacheManager pgb = new PluginCacheManager();
        JellyScriptHousing housing = new JellyScriptHousing( new File( PLUGIN_SCRIPT ).getParentFile(), null );
        FileInputStream fis = new FileInputStream( new File( PLUGIN_SCRIPT ) );
        housing.parse( pgb, PLUGIN_SCRIPT, fis );
        fis.close();

        assertEquals( "Generate docs in APT format>xdoc:generate-from-pom", pgb.getGoalCache()
            .getProperty( "apt:generate" ) );

        assertEquals( "plugin", pgb.getPluginCache().getProperty( "apt:generate" ) );

        assertEquals( "plugin", pgb.getDynaTagLibCache().getProperty( "aptdoc" ) );

        assertEquals( "plugin", pgb.getCallbackCache().getProperty( "xdoc:transform.pre" ) );

        assertEquals( "plugin", pgb.getCallbackCache().getProperty( "foo.post" ) );
    }
}
