package org.apache.maven.project;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.apache.maven.MavenUtils;

/**
 * Test the semantics of basedir inside project.xml.
 *
 * @author Brett Porter <a href="mailto:brett@apache.org">brett@apache.org</a>
 * @version $Id: BasedirTest.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class BasedirTest
    extends TestCase
{
    /**
     * Test relative paths.
     */
    public void testRelativePaths()
        throws Exception
    {
        String basedir = System.getProperty( "basedir" );
        Project p = MavenUtils.getProject( new File( basedir, "src/test/basedir/extend-2/project.xml" ) );
        assertEquals( "check group ID", p.getGroupId(), "maven" );
        assertEquals( "check source directory", p.getBuild().getSourceDirectory(), new File( basedir, "src/java" )
            .getCanonicalPath() );
        assertEquals( "check unit test source directory", p.getBuild().getUnitTestSourceDirectory(),
                      new File( basedir, "src/test" ).getCanonicalPath() );
        assertEquals( "check iutest source directory", p.getBuild().getIntegrationUnitTestSourceDirectory(),
                      new File( basedir, "src/test" ).getCanonicalPath() );
        assertEquals( "check aspect source directory", p.getBuild().getAspectSourceDirectory(), new File( basedir,
                                                                                                          "src/java" )
            .getCanonicalPath() );
    }

    /**
     * Test basedir relative paths.
     */
    public void testRelativePathsWithBasedir()
        throws Exception
    {
        String basedir = System.getProperty( "basedir" );
        Project p = MavenUtils.getProject( new File( basedir, "src/test/basedir/extend-1/project.xml" ) );
        assertEquals( "check group ID", p.getGroupId(), "maven" );
        assertEquals( "check source directory", new File( p.getBuild().getSourceDirectory() ).getCanonicalPath(),
                      new File( basedir, "src/java" ).getCanonicalPath() );
        assertEquals( "check unit test source directory", new File( p.getBuild().getUnitTestSourceDirectory() )
            .getCanonicalPath(), new File( basedir, "src/test" ).getCanonicalPath() );
        assertEquals( "check iutest source directory", new File( p.getBuild().getIntegrationUnitTestSourceDirectory() )
            .getCanonicalPath(), new File( basedir, "src/test" ).getCanonicalPath() );
        assertEquals( "check aspect source directory", new File( p.getBuild().getAspectSourceDirectory() )
            .getCanonicalPath(), new File( basedir, "src/java" ).getCanonicalPath() );
    }

    /**
     * Test relative paths (no ..).
     */
    public void testRelativePathsForwards()
        throws Exception
    {
        String basedir = System.getProperty( "basedir" );
        Project p = MavenUtils.getProject( new File( basedir, "src/test/basedir/project.xml" ) );
        assertEquals( "check group ID", p.getGroupId(), "maven" );
        assertEquals( "check source directory", p.getBuild().getSourceDirectory(),
                      new File( basedir, "src/test/basedir/extend-1" ).getCanonicalPath() );
        assertEquals( "check unit test source directory", p.getBuild().getUnitTestSourceDirectory(),
                      new File( basedir, "src/test/basedir/extend-1" ).getCanonicalPath() );
        assertEquals( "check iutest source directory", p.getBuild().getIntegrationUnitTestSourceDirectory(),
                      new File( basedir, "src/test/basedir/extend-1" ).getCanonicalPath() );
        assertEquals( "check aspect source directory", p.getBuild().getAspectSourceDirectory(),
                      new File( basedir, "src/test/basedir/extend-1" ).getCanonicalPath() );
    }

    /**
     * Generate the test suite.
     * @return the test suite
     */
    public static Test suite()
    {
        return new TestSuite( BasedirTest.class );
    }
}
