package org.apache.maven.util;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Unit test for <code>DVSLPathTool</code>.
 *
 * @author <a href="mailto:pete-apache-dev@kazmier.com">Pete Kazmier</a>
 * @version $Id: DVSLPathToolTest.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class DVSLPathToolTest
    extends TestCase
{
    /**
     * Create the test case
     *
     * @param testName name of the test case
     */
    public DVSLPathToolTest( String testName )
    {
        super( testName );
    }

    /**
     * @return the suite of tests being tested
     */
    public static Test suite()
    {
        return new TestSuite( DVSLPathToolTest.class );
    }

    /**
     * Tests <code>DVSLPathTool.getDirectoryComponent</code>.
     */
    public void testGetDirectoryComponent()
    {
        String[] test = { "file1.xml", "ref/file1", "/home/test/file2.vm", "d1\\d2\\d3\\file", "/d1/d2/" };

        String[] expected = { ".", "ref", "/home/test", "d1\\d2\\d3", "/d1/d2" };

        for ( int i = 0; i < test.length; i++ )
        {
            assertEquals( expected[i], DVSLPathTool.getDirectoryComponent( test[i] ) );
        }
    }

    /**
     * Tests <code>DVSLPathTool.getRelativePath</code>.
     */
    public void testGetRelativePath()
    {
        TestArgs[] tests = {
            new TestArgs( "", "/home/www/html", "", "../.." ),
            new TestArgs( "/", "/home/www/html", "../..", "../.." ),
            new TestArgs( "", "/home/www/html/", "", "../.." ),
            new TestArgs( "/", "/home/www/html/", "../..", "../.." ),
            new TestArgs( "", "home/www/html", "", "../.." ),
            new TestArgs( "/", "home/www/html", "", "../.." ),
            new TestArgs( "", "home/www/html/", "", "../.." ),
            new TestArgs( "/", "home/www/html/", "", "../.." ),
            new TestArgs( "/", "/home", ".", "." ),
            new TestArgs( "/usr/local", null, "", "" ),
            new TestArgs( null, "/usr/local", "", ".." ),
            new TestArgs( null, null, "", "" ),
            new TestArgs( "/home/kaz", "/home/kaz", "", ".." ),
            new TestArgs( "/home/kaz", "/home/kaz/", "", ".." ),
            new TestArgs( "/home/kaz/", "/home/kaz", "", ".." ),
            new TestArgs( "/home/kaz/", "/home/kaz/", "", ".." ),
            new TestArgs( "/home/kaz", "/home/kaz/file.html", ".", "../.." ),
            new TestArgs( "/home/kaz/", "/home/kaz/file.html", ".", "../.." ),
            new TestArgs( "/home/kaz", "/home/kaz/howto/jeff.html", "..", "../../.." ),
            new TestArgs( "/home/", "/home/kaz/howto/images/", "../..", "../../.." ),
            new TestArgs( "/home/", "/home/kaz/howto/jeff.html", "../..", "../../.." ),
            new TestArgs( "/home/", "/home/kaz/howto/u/y/z/jeff.html", "../../../../..", "../../../../../.." ),
            new TestArgs( "/home/boston", "/usr/local/where/am/i", "", "../../../.." ),
            new TestArgs( "home/boston", "/usr/local/where/am/i", "", "../../../.." ),
            new TestArgs( "home/boston", "home/boston/where/am/i", "../..", "../../../.." ),
            new TestArgs( "", "\\home\\www\\html", "", "../.." ),
            new TestArgs( "\\", "\\home\\www\\html", "../..", "../.." ),
            new TestArgs( "", "\\home\\www\\html\\", "", "../.." ),
            new TestArgs( "\\", "\\home\\www\\html\\", "../..", "../.." ),
            new TestArgs( "", "home\\www\\html", "", "../.." ),
            new TestArgs( "\\", "home\\www\\html", "", "../.." ),
            new TestArgs( "", "home\\www\\html\\", "", "../.." ),
            new TestArgs( "\\", "home\\www\\html\\", "", "../.." ),
            new TestArgs( "\\", "\\home", ".", "." ),
            new TestArgs( "\\usr\\local", null, "", "" ),
            new TestArgs( null, "\\usr\\local", "", ".." ),
            new TestArgs( null, null, "", "" ),
            new TestArgs( "\\home\\kaz", "\\home\\kaz", "", ".." ),
            new TestArgs( "\\home\\kaz", "\\home\\kaz\\", "", ".." ),
            new TestArgs( "\\home\\kaz\\", "\\home\\kaz", "", ".." ),
            new TestArgs( "\\home\\kaz\\", "\\home\\kaz\\", "", ".." ),
            new TestArgs( "\\home\\kaz", "\\home\\kaz\\file.html", ".", "../.." ),
            new TestArgs( "\\home\\kaz\\", "\\home\\kaz\\file.html", ".", "../.." ),
            new TestArgs( "\\home\\kaz", "\\home\\kaz\\howto\\jeff.html", "..", "../../.." ),
            new TestArgs( "\\home\\", "\\home\\kaz\\howto\\images\\", "../..", "../../.." ),
            new TestArgs( "\\home\\", "\\home\\kaz\\howto\\jeff.html", "../..", "../../.." ),
            new TestArgs( "\\home\\", "\\home\\kaz\\howto\\u\\y\\z\\jeff.html", "../../../../..", "../../../../../.." ),
            new TestArgs( "\\home\\boston", "\\usr\\local\\where\\am\\i", "", "../../../.." ),
            new TestArgs( "home\\boston", "\\usr\\local\\where\\am\\i", "", "../../../.." ),
            new TestArgs( "home\\boston", "home\\boston\\where\\am\\i", "../..", "../../../.." ),
            new TestArgs( "/x/y/z/", "/x/y/z/a\\b\\c", ".", "../../.." ),
            new TestArgs( "/x/y/z/", "\\x\\y\\z\\a\\b\\c", "", "../../../../.." ),
            new TestArgs( "\\x\\y\\z", "\\x\\y\\z\\a/b\\c", "..", "../../../.." ),
            new TestArgs( "\\x\\y\\z/", "\\x\\y\\z/\\a/b\\c", "..", "../../../.." ),
            new TestArgs( "D:/a/b", "D:/a/b/c", ".", "../../.." ),
            new TestArgs( "d:/a/b", "D:/a/b/c.html", ".", "../../.." ), };

        for ( int i = 0; i < tests.length; i++ )
        {
            assertEquals( tests[i].toString(), tests[i].expected, DVSLPathTool.getRelativePath( tests[i].basedir,
                                                                                                tests[i].filename ) );
        }

        for ( int i = 0; i < tests.length; i++ )
        {
            assertEquals( tests[i].toString(), tests[i].expectedNoBase, DVSLPathTool
                .getRelativePath( tests[i].filename ) );
        }
    }

    /**
     * Value object for a relative path test case.  This class is used
     * when testing the <code>getRelativePath(basedir, filename)</code>
     * and <code>getRelativePath(filename)</code> methods.  The expected
     * results for each method are different which is the reason that
     * both expected values are stored as part of the class.
     *
     * @author <a href="mailto:pete-apache-dev@kazmier.com">Pete Kazmier</a>
     * @version
     * $Id: DVSLPathToolTest.java 517014 2007-03-11 21:15:50Z ltheussl $
     */
    private static class TestArgs
    {
        /** base directory for tests */
        private String basedir;

        /** the file to test*/
        private String filename;

        /**
         * expected result when calling <code>getRelativePath(basedir,
         * filename)</code>.
         */
        private String expected;

        /**
         * expected result when calling <code>getRelativePath(filename)</code>.
         */
        private String expectedNoBase;

        /**
         * Constructor.
         *
         * @param b The base directory.
         * @param f The filename.
         * @param e The expected result when calling
         * <code>getRelativePath(basedir, filename)</code>.
         * @param enb The expected result when calling
         * <code>getRelativePath(filename)</code>.
         */
        TestArgs( String b, String f, String e, String enb )
        {
            basedir = b;
            filename = f;
            expected = e;
            expectedNoBase = enb;
        }

        /**
         * Provide detailed information regarding the test case which
         * can be used as part of the JUnit error message in the event
         * of a unit test failure.
         *
         * @return A string describing the test parameters.
         */
        public String toString()
        {
            StringBuffer sb = new StringBuffer();
            sb.append( "Basedir: " );
            sb.append( basedir );
            sb.append( " Filename: " );
            sb.append( filename );
            return sb.toString();
        }
    }

    public void testUppercaseDrive()
    {
        assertEquals( "c:/b/", "C:/b/", DVSLPathTool.uppercaseDrive( "c:/b/" ) );
        assertEquals( "c:", "C:", DVSLPathTool.uppercaseDrive( "c:" ) );
        assertEquals( ".", ".", DVSLPathTool.uppercaseDrive( "." ) );
        assertEquals( "null", null, DVSLPathTool.uppercaseDrive( null ) );

    }

    public void testCalculateLink( String expected, String link, String relativePath )
    {
        String actual = DVSLPathTool.calculateLink( link, relativePath );
        String function = "DVSLPathTool.calculateLink(" + link + "," + relativePath + ")";
        if ( !expected.equals( actual ) )
        {
            System.out.println( "Function:" + function );
            System.out.println( "Actual:" + actual );
            System.out.println( "Expected:" + expected );
        }
        assertEquals( function, expected, actual );
    }

    public void testCalculateLink()
    {
        testCalculateLink( "/bob.html", "/absolute//bob.html", ".." );
        testCalculateLink( "http://crazyhorse.com", "/absolute/http://crazyhorse.com", ".." );
        testCalculateLink( "http://crazyhorse.com", "http://crazyhorse.com", ".." );
        testCalculateLink( "../index.html", "/index.html", ".." );
        testCalculateLink( "index.html", "/index.html", "." );
        testCalculateLink( "../other-module/index.html", "../other-module/index.html", "." );
        testCalculateLink( "../../other-module/index.html", "../other-module/index.html", ".." );
    }
}
