package org.apache.maven.util;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import junit.framework.TestCase;

public class EnhancedStringTokenizerTest
    extends TestCase
{
    public EnhancedStringTokenizerTest( String name )
    {
        super( name );
    }

    protected void setUp()
        throws Exception
    {
    }

    protected void tearDown()
        throws Exception
    {
    }

    public void testSimple()
    {
        EnhancedStringTokenizer tok = new EnhancedStringTokenizer( "a,b,c,d,,e,,,f,,,,,g", "," );
        checkTokens( tok );
    }

    /**
     * @param tok The tokenizer to check
     */
    private void checkTokens( EnhancedStringTokenizer tok )
    {
        assertEquals( "Token 1", "a", tok.nextToken() );
        assertEquals( "Token 2", "b", tok.nextToken() );
        assertEquals( "Token 3", "c", tok.nextToken() );
        assertEquals( "Token 4", "d", tok.nextToken() );
        assertEquals( "Token 5", "", tok.nextToken() );
        assertEquals( "Token 6", "e", tok.nextToken() );
        assertEquals( "Token 7", "", tok.nextToken() );
        assertEquals( "Token 8", "", tok.nextToken() );
        assertEquals( "Token 9", "f", tok.nextToken() );
        assertEquals( "Token 10", "", tok.nextToken() );
        assertEquals( "Token 11", "", tok.nextToken() );
        assertEquals( "Token 12", "", tok.nextToken() );
        assertEquals( "Token 13", "", tok.nextToken() );
        assertEquals( "Token 14", "g", tok.nextToken() );
        assertEquals( "tok.hasMoreTokens()", false, tok.hasMoreTokens() );
    }

    public void testSimpleTab()
    {
        EnhancedStringTokenizer tok = new EnhancedStringTokenizer( "a\tb\tc\td\t\te\t\t\tf\t\t\t\t\tg", "\t" );
        checkTokens( tok );
    }

    public void testNoDelim()
    {
        EnhancedStringTokenizer tok = new EnhancedStringTokenizer( "a,b,c,d,,e,,,f,,,,,g", "\t" );
        assertEquals( "Token 1", "a,b,c,d,,e,,,f,,,,,g", tok.nextToken() );
        assertEquals( "tok.hasMoreTokens()", false, tok.hasMoreTokens() );
    }

    public void testNoText()
    {
        EnhancedStringTokenizer tok = new EnhancedStringTokenizer( "", "," );
        assertEquals( "tok.hasMoreTokens()", false, tok.hasMoreTokens() );
    }

    public void testReturnDelim()
    {
        EnhancedStringTokenizer tok = new EnhancedStringTokenizer( "a,b,,c,d", ",", true );
        assertEquals( "Token 1", "a", tok.nextToken() );
        assertEquals( "Token 2", ",", tok.nextToken() );
        assertEquals( "Token 3", "b", tok.nextToken() );
        assertEquals( "Token 4", ",", tok.nextToken() );
        assertEquals( "Token 5", "", tok.nextToken() );
        assertEquals( "Token 6", ",", tok.nextToken() );
        assertEquals( "Token 7", "c", tok.nextToken() );
        assertEquals( "Token 2", ",", tok.nextToken() );
        assertEquals( "Token 8", "d", tok.nextToken() );
        assertEquals( "tok.hasMoreTokens()", false, tok.hasMoreTokens() );
    }

    public void testMultipleDelim()
    {
        EnhancedStringTokenizer tok = new EnhancedStringTokenizer( "a.,b.,c.d", ".,", true );
        assertEquals( "Token 1", "a", tok.nextToken() );
        assertEquals( "Token 2", ".", tok.nextToken() );
        assertEquals( "Token 3", "", tok.nextToken() );
        assertEquals( "Token 4", ",", tok.nextToken() );
        assertEquals( "Token 5", "b", tok.nextToken() );
        assertEquals( "Token 6", ".", tok.nextToken() );
        assertEquals( "Token 7", "", tok.nextToken() );
        assertEquals( "Token 8", ",", tok.nextToken() );
        assertEquals( "Token 9", "c", tok.nextToken() );
        assertEquals( "Token 10", ".", tok.nextToken() );
        assertEquals( "Token 11", "d", tok.nextToken() );
        assertEquals( "tok.hasMoreTokens()", false, tok.hasMoreTokens() );
    }

}
