package org.apache.maven.util;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Unit test for <code>MavenTool</code>.
 *
 * @author <a href="mailto:dlr@finemaltcoding.com">Daniel Rall</a>
 * @version $Id: MavenToolTest.java 517014 2007-03-11 21:15:50Z ltheussl $
 */
public class MavenToolTest
    extends TestCase
{
    /** fragment to be resolved */
    private static final String NEEDLE = "org/apache/maven/util/MavenTool.java";

    /** where to search for the fragment */
    private static final String[] HAYSTACK = { "docs", "src" + File.separator + "java", "xdocs" };

    /**
     * Create the test with the given name
     *
     * @param testName the name of the test
     */
    public MavenToolTest( String testName )
    {
        super( testName );
    }

    /**
     * @return the suite of tests being tested
     */
    public static Test suite()
    {
        return new TestSuite( MavenToolTest.class );
    }

    /**
     * Tests {@link MavenTool.resolvePathFragment(String, String, String[])}.
     */
    public void testResolvePathFragment()
    {
        MavenTool tool = new MavenTool();

        /*
         * The basedir for the project is passed into the system properties
         * by the junit task.
         */
        String basedir = System.getProperty( "basedir" );
        assertNotNull( "The system property basedir was not defined.", basedir );

        String path = tool.resolvePathFragment( basedir, NEEDLE, HAYSTACK );
        assertEquals( "Couldn't resolve fragment using a base directory of " + basedir, HAYSTACK[1], path );
    }
}
